@@ -122,6 +122,11 @@ from .src import get_src
     required=False,
     help="Path to global configuration file in .djlintrc format",
 )
+@click.option(
+    "--statistics",
+    is_flag=True,
+    help="Count the number of occurrences of each error/warning code.",
+)
 @colorama_text(autoreset=True)
 def main(
     src: List[str],
@@ -141,6 +146,7 @@ def main(
     format_css: bool,
     format_js: bool,
     configuration: Optional[str],
+    statistics: bool,
 ) -> None:
     """djLint · HTML template linter and formatter."""
     config = Config(
@@ -161,22 +167,27 @@ def main(
         format_css=format_css,
         format_js=format_js,
         configuration=configuration,
+        statistics=statistics,
     )
 
     temp_file = None
 
     if "-" in src:
-        stdin_stream = click.get_text_stream("stdin", encoding="utf8")
-        stdin_text = stdin_stream.read()
+        if config.files:
+            file_list = get_src([Path(x) for x in config.files], config)
 
-        temp_file = tempfile.NamedTemporaryFile(delete=False)
-        temp_file.write(str.encode(stdin_text))
-        temp_file.seek(0)
+        else:
+            stdin_stream = click.get_text_stream("stdin", encoding="utf8")
+            stdin_text = stdin_stream.read()
 
-        # cannot use gitignore for stdin paths.
-        config.use_gitignore = False
+            temp_file = tempfile.NamedTemporaryFile(delete=False)
+            temp_file.write(str.encode(stdin_text))
+            temp_file.seek(0)
 
-        file_list = get_src([Path(temp_file.name)], config)
+            # cannot use gitignore for stdin paths.
+            config.use_gitignore = False
+
+            file_list = get_src([Path(temp_file.name)], config)
 
     else:
         file_list = get_src([Path(x) for x in src], config)
@@ -210,7 +221,7 @@ def main(
             Style.RESET_ALL + "    ",
         )
     )
-    if config.stdin is False or config.lint:
+    if config.stdin is False and config.quiet is False:
         echo()
 
     worker_count = os.cpu_count() or 1
@@ -228,7 +239,7 @@ def main(
         func = partial(process, config)
         futures = {exe.submit(func, this_file): this_file for this_file in file_list}
 
-        if temp_file is None or config.lint:
+        if temp_file is None:
             elapsed = "00:00"
             with tqdm(
                 total=len(file_list),
@@ -266,6 +277,9 @@ def main(
                 leave=True,
             )
             finished_bar.close()
+        else:
+            for future in as_completed(futures):
+                file_errors.append(future.result())
 
     if temp_file and (config.reformat or config.check):
         # if using stdin, only give back formatted code.
