@@ -1,7 +1,8 @@
 """Build djLint console output."""
 import shutil
+from collections import Counter
 from pathlib import Path
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Optional
 
 import regex as re
 from click import echo
@@ -30,7 +31,9 @@ def print_output(
     lint_error_count = 0
     format_error_count = 0
 
-    if config.stdin is False or config.lint:
+    print_blanks = config.stdin is False and config.quiet is False
+
+    if print_blanks:
         echo()
 
     for error in sorted(file_errors, key=lambda x: next(iter(list(x.values())[0]))):
@@ -42,6 +45,9 @@ def print_output(
             # lint message
             lint_error_count += build_output(error["lint_message"], config)
 
+    if config.statistics and config.lint:
+        build_stats_output([x.get("lint_message") for x in file_errors], config)
+
     tense_message = (
         build_quantity(format_error_count) + " would be"
         if config.check is True
@@ -54,22 +60,26 @@ def print_output(
         f"Linted {file_quantity}, found {lint_error_count} {error_case}."
     )
 
-    if config.stdin is False or config.lint:
+    if print_blanks:
         echo()
 
-    if config.stdin is False and (config.reformat or config.check):
+    if (
+        config.quiet is False
+        and config.stdin is False
+        and (config.reformat or config.check)
+    ):
         reformat_success_color = (
             Fore.RED + Style.BRIGHT if (format_error_count) > 0 else Fore.BLUE
         )
         echo(f"{reformat_success_color}{reformat_success_message}{Style.RESET_ALL}")
 
-    if config.lint:
+    if config.lint and config.quiet is False:
         lint_success_color = (
             Fore.RED + Style.BRIGHT if (lint_error_count) > 0 else Fore.BLUE
         )
         echo(f"{lint_success_color}{lint_success_message}{Style.RESET_ALL}")
 
-    if config.stdin is False or config.lint:
+    if print_blanks:
         echo()
 
     return lint_error_count + format_error_count
@@ -96,7 +106,7 @@ def build_output(error: dict, config: Config) -> int:
 
     filename = build_relative_path(list(error.keys())[0], config.project_root.resolve())
 
-    if "{filename}" not in config.linter_output_format:
+    if "{filename}" not in config.linter_output_format and not config.stdin:
         echo(
             f"{Fore.GREEN}{Style.BRIGHT}\n{filename}\n{Style.DIM}"
             + "".join(["─" for x in range(1, width)])
@@ -136,16 +146,7 @@ def build_check_output(errors: dict, config: Config) -> int:
     color = {"-": Fore.YELLOW, "+": Fore.GREEN, "@": Style.BRIGHT + Fore.BLUE}
     width, _ = shutil.get_terminal_size()
 
-    if config.quiet is True and len(list(errors.values())[0]) > 0:
-        echo(
-            Fore.GREEN
-            + Style.BRIGHT
-            + build_relative_path(list(errors.keys())[0], config.project_root.resolve())
-            + Style.DIM
-            + Style.RESET_ALL
-        )
-
-    elif config.quiet is False and len(list(errors.values())[0]) > 0:
+    if config.quiet is False and len(list(errors.values())[0]) > 0:
         echo(
             Fore.GREEN
             + Style.BRIGHT
@@ -180,3 +181,43 @@ def build_quantity_tense(size: int) -> str:
         + " "
         + ("were" if size > 1 or size == 0 else "was")
     )
+
+
+def build_stats_output(errors: List[Optional[Any]], config: Config) -> int:
+    """Build output for linter statistics."""
+    if len(errors) == 0:
+        return 0
+
+    codes = []
+    for error in errors:
+        if error:
+            for code in list(error.values())[0]:
+                codes.append(code["code"])
+
+    messages = {
+        rule["rule"]["name"]: rule["rule"]["message"] for rule in config.linter_rules
+    }
+
+    echo()
+    width, _ = shutil.get_terminal_size()
+    echo(
+        f"{Fore.GREEN}{Style.BRIGHT}Statistics{Style.RESET_ALL}\n{Style.DIM}{'─' * width}{Style.RESET_ALL}"
+    )
+
+    if messages and codes:
+
+        longest_code = len(max(messages.keys(), key=len))
+        longest_count = len(
+            str(max(Counter(codes).values(), key=lambda x: len(str(x))))
+        )
+
+        for code in sorted(Counter(codes).items()):
+
+            code_space = (longest_code - len(str(code[0]))) * " "
+            count_space = (longest_count - len(str(code[1]))) * " "
+
+            echo(
+                f"{Fore.YELLOW}{code[0]}{Fore.BLUE} {code_space}{code[1]}{Style.RESET_ALL} {count_space}{messages[code[0]]}"
+            )
+
+    return sum(Counter(codes).values())
